@@ -552,7 +552,8 @@ namespace gdestraier {
       model_->clear();    // Clear all rows in model.
 
       // 追加中はソートの為の比較を抑止する
-      model_->set_sort_column(Gtk::TreeSortable::DEFAULT_UNSORTED_COLUMN_ID, Gtk::SORT_ASCENDING);
+      model_->set_sort_column(GTK_TREE_SORTABLE_UNSORTED_SORT_COLUMN_ID,
+                              Gtk::SORT_ASCENDING);
 
       switch (group_key_) {
       case gdestraier::model::preferences::GROUP_BY_NONE:
